<?php
/*
Plugin Name: Easy format post
Author: Elbaz Michael
Plugin URI: https://fr.wordpress.org/plugins/easy-format-post/
Version: 1.1
Licence: GPLv2 or later
Description: Wrap email and phone number automatically eg: 00123456789 become &lt;a href=&quot;tel:00123456789&quot;&gt;00123456789&lt;/a&gt; or test@test.com become &lt;a href=&quot;mailto:test@test.com&quot;&gt;test@test.com&lt;/a&gt;
*/


//DB
include_once 'easy-format-post-db.php';
register_activation_hook(__FILE__, 'efp_install_data');

define('EFP_APP_NAME', 'Easy format post');
define('EFP_ROOT', plugin_dir_path(__FILE__));

add_filter('the_content', 'efp_format_post_format', 9);
function efp_format_post_format($content)
{
    $input_min = 'efp_phone_min';
    $input_max = 'efp_phone_max';

    //Get DB data
    $efp_phone_min = get_option($input_min);
    $efp_phone_max = get_option($input_max);

    //Phone number
    $new_content = preg_replace_callback('/([0-9. _-]{' . $efp_phone_min . ',' . $efp_phone_max . '})/', function ($matches) {
        return '<a href="tel:' . preg_replace('/[\D]/', '', $matches[1]) . '">' . $matches[1] . '</a>';
    }, $content);
    //Email
    $new_content = preg_replace('/([a-zA-Z0-9._-]{1,70}@[A-Za-z0-9.-]+\.[a-zA-Z]{2,6})/', '<a href="mailto:$1">$1</a>', $new_content);
    return $new_content;
}


add_action('admin_menu', 'efp_add_admin_menu');
function efp_menu_html()
{
    include EFP_ROOT . '/easy-format-post-admin.php';
}

function efp_add_admin_menu()
{
    $hook = add_menu_page(EFP_APP_NAME, EFP_APP_NAME, 'manage_options', 'format-post-admin', 'efp_menu_html');
    add_action('load-' . $hook, 'efp_admin_process_action');
}

function efp_admin_process_action()
{

    $input_min = 'efp_phone_min';
    $input_max = 'efp_phone_max';

    if (isset($_POST[$input_min]) && isset($_POST[$input_max])) {
        //Sanitize data
        $efp_phone_min_sanitize = filter_input(INPUT_POST, $input_min, FILTER_CALLBACK, ['options' => 'absint']);
        $efp_phone_max_sanitize = filter_input(INPUT_POST, $input_max, FILTER_CALLBACK, ['options' => 'absint']);

        $efp_phone_min = $efp_phone_min_sanitize > 0 ? $efp_phone_min_sanitize : $efp_phone_min_sanitize;
        $efp_phone_max = $efp_phone_max_sanitize > 0 ? $efp_phone_max_sanitize : $efp_phone_max_sanitize;

        //Saving into DB
        $efp_phone_min = $efp_phone_min >= $efp_phone_max ? $efp_phone_max : $efp_phone_min;
        update_option($input_min, $efp_phone_min);
        update_option($input_max, $efp_phone_max);
    }

    //Get DB data
    $_POST[$input_min] = get_option($input_min);
    $_POST[$input_max] = get_option($input_max);
}
